@@ -399,12 +399,14 @@ sub ourInitVertexBuffers
   }
   else
   {
+    print "Using classic Vertex Buffers\n";
     glVertexPointer_p(3, $verts);
     glNormalPointer_p($norms);
     $colors->assign($rainbow_offset,@rainbow);
     glColorPointer_p(4, $colors);
     glTexCoordPointer_p(2, $texcoords);
   }
+  print "-- done\n";
 }
 
 sub ourInit
@@ -472,6 +474,7 @@ sub ourBuildTextures
   if ($hasImage && -e $Tex_File)
   {
     my $img = new OpenGL::Image(source=>$Tex_File);
+    die $@ if $@;
     my($eng,$ver) = $img->Get('engine','version');
     print "Using OpenGL::Image - $eng v$ver\n";
 
@@ -639,7 +642,7 @@ sub ourBuildTextures
     glFramebufferTexture2DEXT(GL_FRAMEBUFFER_EXT, GL_COLOR_ATTACHMENT0_EXT,
       GL_TEXTURE_2D, $TextureID_FBO, 0);
     glBindRenderbufferEXT(GL_RENDERBUFFER_EXT, $RenderBufferID);
-    glRenderbufferStorageEXT(GL_RENDERBUFFER_EXT, GL_DEPTH_COMPONENT24,
+    glRenderbufferStorageEXT(GL_RENDERBUFFER_EXT, GL_DEPTH_COMPONENT24_ARB,
       $Tex_Width, $Tex_Height);
     glFramebufferRenderbufferEXT(GL_FRAMEBUFFER_EXT, GL_DEPTH_ATTACHMENT_EXT,
       GL_RENDERBUFFER_EXT, $RenderBufferID);
